pub trait CollaborationReceiver: Send {
// Required method
fn recv<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Option<CollaborationEvent>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Async trait for receiving collaboration events from a transport.
Each receiver gets its own independent stream of events published after the subscription was created.